@@ -34,6 +34,9 @@
 
 #pragma once
 
+#include <filesystem>
+#include <memory>
+
 #include <pdal/Options.hpp>
 #include <pdal/PointView.hpp>
 #include <pdal/Stage.hpp>
@@ -41,33 +44,44 @@
 namespace pdal
 {
 
-class Writer;
 class UserCallback;
 
+namespace expr
+{
+    class ConditionalExpression;
+}
+
 /**
   A Writer is a terminal stage for a PDAL pipeline.  It usually writes output
   to a file, but this isn't a requirement.  The class provides support for
   some operations common for producing point output.
 */
-class PDAL_DLL Writer : public virtual Stage
+class PDAL_EXPORT Writer : public virtual Stage
 {
     friend class WriterWrapper;
     friend class DbWriter;
     friend class FlexWriter;
 
+    struct Args;
+
 public:
-    /**
-      Construct a writer.
-    */
-    Writer()
-        {}
+    Writer();
+    ~Writer();
+    Writer& operator=(const Writer&) = delete;
+    Writer(const Writer&) = delete;
+
+    std::string filename() const;
+    void setFilename(const std::string& filename);
 
     /**
       Locate template placeholder ('#') and validate filename with respect
       to placeholder.
     */
-    static std::string::size_type
-        handleFilenameTemplate(const std::string& filename);
+    static std::string::size_type handleFilenameTemplate(const std::string& filename);
+    /**
+      Replace special tags (such as '#uuid#') with something (like a UUID string).
+    */
+    static std::string replaceTags(std::string filename);
 
 private:
     virtual PointViewSet run(PointViewPtr view)
@@ -77,18 +91,28 @@ private:
         viewSet.insert(view);
         return viewSet;
     }
-    virtual void writerInitialize(PointTableRef table)
-    {}
+    virtual void l_addArgs(ProgramArgs& args) final;
+    virtual void l_initialize(PointTableRef table);
+    virtual void l_prepared(PointTableRef table) final;
 
+    virtual const expr::ConditionalExpression *whereExpr() const;
+    virtual WhereMergeMode mergeMode() const;
     /**
       Write the point in a PointView.  This is a simplification of the
       \ref run() interface for convenience.  Impelment in subclass if desired.
     */
     virtual void write(const PointViewPtr /*view*/)
         { std::cerr << "Can't write with stage = " << getName() << "!\n"; }
+    virtual void assignParsedOptions() final
+    {}
 
-    Writer& operator=(const Writer&); // not implemented
-    Writer(const Writer&); // not implemented
+    std::unique_ptr<Args> m_args;
+};
+
+class PDAL_EXPORT NoFilenameWriter : public Writer
+{
+public:
+    using Writer::Writer;
 };
 
 } // namespace pdal
